@@ -22,13 +22,13 @@ namespace Akonadi
 {
 class IncidenceChanger;
 
-class Q_DECL_HIDDEN CalendarClipboard::Private : public QObject
+class CalendarClipboardPrivate : public QObject
 {
     Q_OBJECT
 public:
-    Private(const Akonadi::CalendarBase::Ptr &calendar, Akonadi::IncidenceChanger *changer, CalendarClipboard *qq);
+    CalendarClipboardPrivate(const Akonadi::CalendarBase::Ptr &calendar, Akonadi::IncidenceChanger *changer, CalendarClipboard *qq);
 
-    ~Private();
+    ~CalendarClipboardPrivate() override;
 
     /**
      * Returns all uids of incidenes having @p incidence has their parent (or grand parent, etc.)
@@ -38,7 +38,7 @@ public:
 
     /**
      * Copies all these incidences to clipboard. Deletes them.
-     * This function assumes the caller already unparented all childs ( made them independent ).
+     * This function assumes the caller already unparented all children ( made them independent ).
      */
     void cut(const KCalendarCore::Incidence::List &incidences);
 
@@ -48,7 +48,7 @@ public:
     void cut(const KCalendarCore::Incidence::Ptr &incidence);
 
     /**
-     * All immediate childs of @p incidence are made independent.
+     * All immediate children of @p incidence are made independent.
      * Their RELATED-TO field is cleared.
      *
      * After it's done, signal makeChildsIndependentFinished() is emitted.
